__package_name__ = 'lightning-grid'
__version__ = '0.8.8'
__logo__ = """


     ========     ==========    ===========   ==========         ===    ======
   ============   ============  ===========   ============      == ==     ==
   ===            ===      ===      ===       ===      === === =======  ======
   ===   ======   ============      ===       ===      ===
   ======   ===   ===    ====   ===========   ============
      ===   ===   ===      ===  ===========   =========

    """
